import React from "react";
import { useApplicationTheme } from "../../../providers/ThemeProvider";
import { Grid, Paper, FormControlLabel, Switch } from "@mui/material";
import LanguageContainer from "./language/LanguageContainer";
import { PaperTitle } from "components/common";
import { makeStyles } from "@mui/material/styles";
import { useTranslation } from "react-i18next";

const useStyles = makeStyles(theme => ({
  language: {
    paddingLeft: theme.spacing(1)
  }
}));

const AppearanceComponent = () => {
  const { isDark, onDarkModeChanged } = useApplicationTheme();
  const { t } = useTranslation();
  const classes = useStyles();

  const handleChange = event => {
    const { checked } = event.target;
    onDarkModeChanged(checked);
  };

  return (
    <Paper variant="outlined">
      <PaperTitle text={t("Settings.Appearance.Title")} />
      <Grid container spacing={0}>
        <Grid item xs={12} sm={6} md={4} lg={3}>
          <FormControlLabel
            value="start"
            control={<Switch checked={isDark} onChange={handleChange} color="secondary" name="dark-mode-switch" />}
            label="Dark mode:"
            labelPlacement="start"
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4} lg={3}>
          <FormControlLabel
            value="start"
            control={
              <div className={classes.language}>
                <LanguageContainer />
              </div>
            }
            label="Language:"
            labelPlacement="start"
          />
        </Grid>
      </Grid>
    </Paper>
  );
};

export default AppearanceComponent;
